@@ -3,10 +3,10 @@
  *  Module    : proto.h
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   :
- *  Updated   : 2020-05-20
+ *  Updated   : 2021-02-23
  *  Notes     :
  *
- * Copyright (c) 1997-2020 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2021 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -69,6 +69,8 @@ extern void load_newnews_info(char *info);
 /* art.c */
 extern int find_artnum(t_artnum art);
 extern int global_get_multipart_info(int aindex, MultiPartInfo *setme);
+extern int global_get_multiparts(int aindex, MultiPartInfo **malloc_and_setme_info, t_bool tagging);
+extern t_bool global_look_for_multipart(int aindex, char start, char stop);
 extern t_bool index_group(struct t_group *group);
 extern void do_update(t_bool catchup);
 extern void find_base(struct t_group *group);
@@ -377,7 +379,6 @@ extern void copy_body(FILE *fp_ip, FILE *fp_op, char *prefix, char *initl, t_boo
 extern void create_index_lock_file(char *the_lock_file);
 extern void dir_name(const char *fullpath, char *dir);
 extern void draw_mark_selected(int i);
-extern void draw_percent_mark(long cur_num, long max_num);
 extern void get_author(t_bool thread, struct t_article *art, char *str, size_t len);
 extern void get_cwd(char *buf);
 extern void make_base_group_path(const char *base_dir, const char *group_name, char *group_path, size_t group_path_len);
@@ -499,9 +500,10 @@ extern int repost_article(const char *groupname, int respnum, t_bool supersede,
 extern t_bool cancel_article(struct t_group *group, struct t_article *art, int respnum);
 extern t_bool mail_bug_report(void);
 extern t_bool pickup_postponed_articles(t_bool ask, t_bool all);
+extern t_bool post_hist_page(void);
 extern t_bool post_article(const char *groupname);
 extern t_bool reread_active_after_posting(void);
-extern t_bool user_posted_messages(void);
+extern t_posted *find_post_hist(int n);
 extern void init_postinfo(void);
 extern void quick_post_article(t_bool postponed_only, int num_cmd_line_groups);
 #if defined(SIGWINCH) || defined(SIGTSTP)
@@ -532,6 +534,9 @@ extern void prompt_yn_redraw(void);
 
 /* read.c */
 extern char *tin_fgets(FILE *fp, t_bool header);
+#ifdef HAVE_SELECT
+	extern t_bool wait_for_input(void);
+#endif /* HAVE_SELECT */
 #ifdef NNTP_ABLE
 	extern void drain_buffer(FILE *fp);
 #endif /* NNTP_ABLE */
@@ -586,7 +591,7 @@ extern void compose_mail_text_plain(const char *filename, struct t_group *group)
 extern int check_start_save_any_news(int function, t_bool catchup);
 extern t_bool create_path(const char *path);
 extern t_bool post_process_files(t_function proc_type_func, t_bool auto_delete);
-extern t_bool save_and_process_art(t_openartinfo *artinfo, struct t_article *artptr, t_bool is_mailbox, const char *inpath, int max, t_bool post_process);
+extern t_bool save_and_process_art(t_openartinfo *artinfo, t_bool is_mailbox, const char *inpath, int max, t_bool post_process);
 extern t_part *get_part(int n);
 extern t_url *find_url(int n);
 extern void attachment_page(t_openartinfo *art);
@@ -622,6 +627,7 @@ extern void reset_srch_offsets(void);
 /* select.c */
 extern int add_my_group(const char *group, t_bool add, t_bool ignore_case);
 extern int choose_new_group(void);
+extern int show_article_by_msgid(char *messageid);
 extern int skip_newgroups(void);
 extern void selection_page(int start_groupnum, int num_cmd_line_groups);
 extern void show_selection_page(void);
@@ -718,7 +724,7 @@ extern int my_toupper(int);
 
 /* tags.c */
 extern int line_is_tagged(int n);
-extern int tag_multipart(int base_index);
+extern int tag_multipart(int arts_index);
 extern t_bool arts_selected(void);
 extern t_bool set_range(int level, int min, int max, int curr);
 extern t_bool tag_article(int art);
