@@ -3,10 +3,10 @@
  *  Module    : version.h
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2019-02-18
+ *  Updated   : 2021-02-01
  *  Notes     :
  *
- * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,15 +43,15 @@
 
 #	define PRODUCT		"tin"
 #	ifndef TIN_AUTOCONF_H
-#		define VERSION		"2.4.5"
+#		define VERSION		"2.4.6"
 #	endif /* !TIN_AUTOCONF_H */
-#	define RELEASEDATE	"20200522"
-#	define RELEASENAME	"Millburn"
+#	define RELEASEDATE	"20210226"
+#	define RELEASENAME	"Glen Albyn"
 /* config-file versions - must by dotted triples in the range 0 to 99 each */
-#	define TINRC_VERSION	"1.3.17"
-#	define ATTRIBUTES_VERSION	"1.0.10"
-#	define FILTER_VERSION	"1.0.1"
-#	define KEYMAP_VERSION	"1.0.9"
+#	define TINRC_VERSION	"1.3.18"
+#	define ATTRIBUTES_VERSION	"1.0.11"
+#	define FILTER_VERSION	"1.0.2"
+#	define KEYMAP_VERSION	"1.0.10"
 #	define SERVERCONFIG_VERSION	"1.0.0"
 
 #endif /* !VERSION_H */
