@@ -3,10 +3,10 @@
  *  Module    : attrib.c
  *  Author    : I. Lea
  *  Created   : 1993-12-01
- *  Updated   : 2020-04-23
+ *  Updated   : 2021-02-23
  *  Notes     : Group attribute routines
  *
- * Copyright (c) 1993-2020 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -58,6 +58,7 @@ int attrib_file_offset;
 /*
  * Local prototypes
  */
+static t_bool skip_scope(struct t_scope *scope);
 static void set_attrib(int type, const char *scope, const char *line, void *data);
 static void set_default_attributes(struct t_attribute *attributes, struct t_attribute *scope, t_bool global);
 static void set_default_state(struct t_attribute_state *state);
@@ -69,6 +70,8 @@ static void set_default_state(struct t_attribute_state *state);
 #	endif /* 0 */
 #endif /* DEBUG */
 
+#define CopyBits(target,source) attributes->target = CAST_BITS(source,target)
+#define CopyBool(target,source) attributes->target = CAST_BOOL(source)
 
 /*
  * Per group attributes. This fills out a basic template of defaults
@@ -102,65 +105,64 @@ set_default_attributes(
 	attributes->ispell = NULL;
 #endif /* HAVE_ISPELL */
 	attributes->quick_kill_scope = (scope ? scope->quick_kill_scope : (global ? (tinrc.default_filter_kill_global ? my_strdup("*") : NULL) : NULL));
-	attributes->quick_kill_header = tinrc.default_filter_kill_header;
-	attributes->quick_kill_case = tinrc.default_filter_kill_case;
-	attributes->quick_kill_expire = tinrc.default_filter_kill_expire;
+	CopyBits(quick_kill_header, tinrc.default_filter_kill_header);
+	CopyBool(quick_kill_case, tinrc.default_filter_kill_case);
+	CopyBool(quick_kill_expire, tinrc.default_filter_kill_expire);
 	attributes->quick_select_scope = (scope ? scope->quick_select_scope : (global ? (tinrc.default_filter_select_global ? my_strdup("*") : NULL) : NULL));
-	attributes->quick_select_header = tinrc.default_filter_select_header;
-	attributes->quick_select_case = tinrc.default_filter_select_case;
-	attributes->quick_select_expire = tinrc.default_filter_select_expire;
-	attributes->show_only_unread_arts = tinrc.show_only_unread_arts;
-	attributes->thread_articles = tinrc.thread_articles;
-	attributes->thread_catchup_on_exit = tinrc.thread_catchup_on_exit;
-	attributes->thread_perc = tinrc.thread_perc;
-	attributes->sort_article_type = tinrc.sort_article_type;
-	attributes->sort_threads_type = tinrc.sort_threads_type;
-	attributes->show_author = tinrc.show_author;
-	attributes->show_signatures = tinrc.show_signatures;
-	attributes->trim_article_body = tinrc.trim_article_body;
-	attributes->verbatim_handling = tinrc.verbatim_handling;
+	CopyBits(quick_select_header, tinrc.default_filter_select_header);
+	CopyBool(quick_select_case, tinrc.default_filter_select_case);
+	CopyBool(quick_select_expire, tinrc.default_filter_select_expire);
+	CopyBool(show_only_unread_arts, tinrc.show_only_unread_arts);
+	CopyBits(thread_articles, tinrc.thread_articles);
+	CopyBool(thread_catchup_on_exit, tinrc.thread_catchup_on_exit);
+	CopyBits(thread_perc, tinrc.thread_perc);
+	CopyBits(sort_article_type, tinrc.sort_article_type);
+	CopyBits(sort_threads_type, tinrc.sort_threads_type);
+	CopyBits(show_author, tinrc.show_author);
+	CopyBool(show_signatures, tinrc.show_signatures);
+	CopyBits(trim_article_body, tinrc.trim_article_body);
+	CopyBool(verbatim_handling, tinrc.verbatim_handling);
 #ifdef HAVE_COLOR
-	attributes->extquote_handling = tinrc.extquote_handling;
+	CopyBool(extquote_handling, tinrc.extquote_handling);
 #endif /* HAVE_COLOR */
-	attributes->wrap_on_next_unread = tinrc.wrap_on_next_unread;
-	attributes->add_posted_to_filter = tinrc.add_posted_to_filter;
-	attributes->advertising = tinrc.advertising;
-	attributes->alternative_handling = tinrc.alternative_handling;
-	attributes->ask_for_metamail = tinrc.ask_for_metamail;
-	attributes->auto_cc_bcc = tinrc.auto_cc_bcc;
-	attributes->auto_list_thread = tinrc.auto_list_thread;
-	attributes->auto_save = tinrc.auto_save;
+	CopyBool(wrap_on_next_unread, tinrc.wrap_on_next_unread);
+	CopyBool(add_posted_to_filter, tinrc.add_posted_to_filter);
+	CopyBool(advertising, tinrc.advertising);
+	CopyBool(alternative_handling, tinrc.alternative_handling);
+	CopyBool(ask_for_metamail, tinrc.ask_for_metamail);
+	CopyBits(auto_cc_bcc, tinrc.auto_cc_bcc);
+	CopyBool(auto_list_thread, tinrc.auto_list_thread);
 	attributes->auto_select = FALSE;
-	attributes->batch_save = tinrc.batch_save;
+	CopyBool(batch_save, tinrc.batch_save);
 	attributes->delete_tmp_files = FALSE;
-	attributes->group_catchup_on_exit = tinrc.group_catchup_on_exit;
-	attributes->mail_8bit_header = tinrc.mail_8bit_header;
-	attributes->mail_mime_encoding = tinrc.mail_mime_encoding;
-	attributes->mark_ignore_tags = tinrc.mark_ignore_tags;
-	attributes->mark_saved_read = tinrc.mark_saved_read;
+	CopyBool(group_catchup_on_exit, tinrc.group_catchup_on_exit);
+	CopyBool(mail_8bit_header, tinrc.mail_8bit_header);
+	CopyBits(mail_mime_encoding, tinrc.mail_mime_encoding);
+	CopyBool(mark_ignore_tags, tinrc.mark_ignore_tags);
+	CopyBool(mark_saved_read, tinrc.mark_saved_read);
 	attributes->news_headers_to_display = (global ? tinrc.news_headers_to_display : NULL);
 	attributes->headers_to_display = (scope ? (scope->headers_to_display ? scope->headers_to_display : NULL) : NULL);
 	attributes->news_headers_to_not_display = (global ? tinrc.news_headers_to_not_display : NULL);
 	attributes->headers_to_not_display = (scope ? (scope->headers_to_not_display ? scope->headers_to_not_display : NULL) : NULL);
-	attributes->pos_first_unread = tinrc.pos_first_unread;
-	attributes->post_8bit_header = tinrc.post_8bit_header;
-	attributes->post_mime_encoding = tinrc.post_mime_encoding;
-	attributes->post_process_view = tinrc.post_process_view;
-	attributes->post_process_type = tinrc.post_process_type;
+	CopyBool(pos_first_unread, tinrc.pos_first_unread);
+	CopyBool(post_8bit_header, tinrc.post_8bit_header);
+	CopyBits(post_mime_encoding, tinrc.post_mime_encoding);
+	CopyBool(post_process_view, tinrc.post_process_view);
+	CopyBits(post_process_type, tinrc.post_process_type);
 #ifndef DISABLE_PRINTING
-	attributes->print_header = tinrc.print_header;
+	CopyBool(print_header, tinrc.print_header);
 #endif /* !DISABLE_PRINTING */
-	attributes->process_only_unread = tinrc.process_only_unread;
-	attributes->prompt_followupto = tinrc.prompt_followupto;
-	attributes->sigdashes = tinrc.sigdashes;
-	attributes->signature_repost = tinrc.signature_repost;
-	attributes->start_editor_offset = tinrc.start_editor_offset;
+	CopyBool(process_only_unread, tinrc.process_only_unread);
+	CopyBool(prompt_followupto, tinrc.prompt_followupto);
+	CopyBool(sigdashes, tinrc.sigdashes);
+	CopyBool(signature_repost, tinrc.signature_repost);
+	CopyBool(start_editor_offset, tinrc.start_editor_offset);
 	attributes->x_comment_to = FALSE;
-	attributes->tex2iso_conv = tinrc.tex2iso_conv;
+	CopyBool(tex2iso_conv, tinrc.tex2iso_conv);
 	attributes->mime_forward = FALSE;
 	attributes->fcc = NULL;
 #ifdef CHARSET_CONVERSION
-	attributes->mm_network_charset = tinrc.mm_network_charset;
+	CopyBits(mm_network_charset, tinrc.mm_network_charset);
 	attributes->undeclared_charset = NULL;
 #endif /* CHARSET_CONVERSION */
 }
@@ -176,7 +178,6 @@ set_default_state(
 	state->ask_for_metamail = FALSE;
 	state->auto_cc_bcc = FALSE;
 	state->auto_list_thread = FALSE;
-	state->auto_save = FALSE;
 	state->auto_select = FALSE;
 	state->batch_save = FALSE;
 	state->date_format = FALSE;
@@ -352,7 +353,6 @@ read_attributes_file(
 					MATCH_BOOLEAN("ask_for_metamail=", OPT_ATTRIB_ASK_FOR_METAMAIL);
 					MATCH_INTEGER("auto_cc_bcc=", OPT_ATTRIB_AUTO_CC_BCC, AUTO_CC_BCC);
 					MATCH_BOOLEAN("auto_list_thread=", OPT_ATTRIB_AUTO_LIST_THREAD);
-					MATCH_BOOLEAN("auto_save=", OPT_ATTRIB_AUTO_SAVE);
 					MATCH_BOOLEAN("auto_select=", OPT_ATTRIB_AUTO_SELECT);
 					break;
 
@@ -524,7 +524,7 @@ read_attributes_file(
 				switch (my_tolower((unsigned char) line[0])) {
 					case 'a':
 						if (match_boolean(line, "auto_bcc=", &auto_bcc)) {
-							if (scopes[num_scope -1].attribute->auto_cc_bcc & AUTO_CC)
+							if (scopes[num_scope - 1].attribute->auto_cc_bcc & AUTO_CC)
 								auto_cc_bcc = (auto_bcc ? AUTO_CC_BCC : AUTO_CC);
 							else
 								auto_cc_bcc = (auto_bcc ? AUTO_BCC : 0);
@@ -533,7 +533,7 @@ read_attributes_file(
 							break;
 						}
 						if (match_boolean(line, "auto_cc=", &auto_cc)) {
-							if (scopes[num_scope -1].attribute->auto_cc_bcc & AUTO_BCC)
+							if (scopes[num_scope - 1].attribute->auto_cc_bcc & AUTO_BCC)
 								auto_cc_bcc = (auto_cc ? AUTO_CC_BCC : AUTO_BCC);
 							else
 								auto_cc_bcc = (auto_cc ? AUTO_CC : 0);
@@ -541,6 +541,14 @@ read_attributes_file(
 							found = TRUE;
 							break;
 						}
+						/* option removed */
+						if (upgrade && upgrade->file_version < 10011) {
+							t_bool ignore;
+
+							if (match_boolean(line, "auto_save=", &ignore))
+								found = TRUE;
+							break;
+						}
 						break;
 
 					case 'p':
@@ -668,11 +676,16 @@ read_attributes_file(
 	curr_scope->attribute->string = my_strdup((char *) data); \
 	curr_scope->state->string = TRUE; \
 	break
-#define SET_INTEGER(integer) \
-	curr_scope->attribute->integer = *((int *) data); \
-	curr_scope->state->integer = TRUE; \
+
+#define SET_INTEGER(value) \
+	curr_scope->attribute->value = CAST_BITS(*((int *) data), value); \
+	curr_scope->state->value = TRUE; \
 	break
 
+#define SET_BOOLEAN(value) \
+	curr_scope->attribute->value = CAST_BOOL(*((int *) data)); \
+	curr_scope->state->value = TRUE; \
+	break
 
 static void
 set_attrib(
@@ -720,58 +733,55 @@ set_attrib(
 				SET_STRING(followup_to);
 
 			case OPT_ATTRIB_ADD_POSTED_TO_FILTER:
-				SET_INTEGER(add_posted_to_filter);
+				SET_BOOLEAN(add_posted_to_filter);
 
 			case OPT_ATTRIB_ADVERTISING:
-				SET_INTEGER(advertising);
+				SET_BOOLEAN(advertising);
 
 			case OPT_ATTRIB_ALTERNATIVE_HANDLING:
-				SET_INTEGER(alternative_handling);
+				SET_BOOLEAN(alternative_handling);
 
 			case OPT_ATTRIB_ASK_FOR_METAMAIL:
-				SET_INTEGER(ask_for_metamail);
+				SET_BOOLEAN(ask_for_metamail);
 
 			case OPT_ATTRIB_AUTO_CC_BCC:
 				SET_INTEGER(auto_cc_bcc);
 
 			case OPT_ATTRIB_AUTO_LIST_THREAD:
-				SET_INTEGER(auto_list_thread);
+				SET_BOOLEAN(auto_list_thread);
 
 			case OPT_ATTRIB_AUTO_SELECT:
-				SET_INTEGER(auto_select);
-
-			case OPT_ATTRIB_AUTO_SAVE:
-				SET_INTEGER(auto_save);
+				SET_BOOLEAN(auto_select);
 
 			case OPT_ATTRIB_BATCH_SAVE:
-				SET_INTEGER(batch_save);
+				SET_BOOLEAN(batch_save);
 
 			case OPT_ATTRIB_DATE_FORMAT:
 				SET_STRING(date_format);
 
 			case OPT_ATTRIB_DELETE_TMP_FILES:
-				SET_INTEGER(delete_tmp_files);
+				SET_BOOLEAN(delete_tmp_files);
 
 			case OPT_ATTRIB_EDITOR_FORMAT:
 				SET_STRING(editor_format);
 
 			case OPT_ATTRIB_GROUP_CATCHUP_ON_EXIT:
-				SET_INTEGER(group_catchup_on_exit);
+				SET_BOOLEAN(group_catchup_on_exit);
 
 			case OPT_ATTRIB_GROUP_FORMAT:
 				SET_STRING(group_format);
 
 			case OPT_ATTRIB_MAIL_8BIT_HEADER:
-				SET_INTEGER(mail_8bit_header);
+				SET_BOOLEAN(mail_8bit_header);
 
 			case OPT_ATTRIB_MAIL_MIME_ENCODING:
 				SET_INTEGER(mail_mime_encoding);
 
 			case OPT_ATTRIB_MARK_IGNORE_TAGS:
-				SET_INTEGER(mark_ignore_tags);
+				SET_BOOLEAN(mark_ignore_tags);
 
 			case OPT_ATTRIB_MARK_SAVED_READ:
-				SET_INTEGER(mark_saved_read);
+				SET_BOOLEAN(mark_saved_read);
 
 			case OPT_ATTRIB_NEWS_HEADERS_TO_DISPLAY:
 				FreeIfNeeded(curr_scope->attribute->news_headers_to_display);
@@ -788,50 +798,50 @@ set_attrib(
 				break;
 
 			case OPT_ATTRIB_POS_FIRST_UNREAD:
-				SET_INTEGER(pos_first_unread);
+				SET_BOOLEAN(pos_first_unread);
 
 			case OPT_ATTRIB_POST_8BIT_HEADER:
-				SET_INTEGER(post_8bit_header);
+				SET_BOOLEAN(post_8bit_header);
 
 			case OPT_ATTRIB_POST_MIME_ENCODING:
 				SET_INTEGER(post_mime_encoding);
 
 			case OPT_ATTRIB_POST_PROCESS_VIEW:
-				SET_INTEGER(post_process_view);
+				SET_BOOLEAN(post_process_view);
 
 #ifndef DISABLE_PRINTING
 			case OPT_ATTRIB_PRINT_HEADER:
-				SET_INTEGER(print_header);
+				SET_BOOLEAN(print_header);
 #endif /* !DISABLE_PRINTING */
 
 			case OPT_ATTRIB_PROCESS_ONLY_UNREAD:
-				SET_INTEGER(process_only_unread);
+				SET_BOOLEAN(process_only_unread);
 
 			case OPT_ATTRIB_PROMPT_FOLLOWUPTO:
-				SET_INTEGER(prompt_followupto);
+				SET_BOOLEAN(prompt_followupto);
 
 #ifdef HAVE_COLOR
 			case OPT_ATTRIB_EXTQUOTE_HANDLING:
-				SET_INTEGER(extquote_handling);
+				SET_BOOLEAN(extquote_handling);
 #endif /* HAVE_COLOR */
 
 			case OPT_ATTRIB_SHOW_ONLY_UNREAD_ARTS:
-				SET_INTEGER(show_only_unread_arts);
+				SET_BOOLEAN(show_only_unread_arts);
 
 			case OPT_ATTRIB_SIGDASHES:
-				SET_INTEGER(sigdashes);
+				SET_BOOLEAN(sigdashes);
 
 			case OPT_ATTRIB_SIGNATURE_REPOST:
-				SET_INTEGER(signature_repost);
+				SET_BOOLEAN(signature_repost);
 
 			case OPT_ATTRIB_START_EDITOR_OFFSET:
-				SET_INTEGER(start_editor_offset);
+				SET_BOOLEAN(start_editor_offset);
 
 			case OPT_ATTRIB_THREAD_ARTICLES:
 				SET_INTEGER(thread_articles);
 
 			case OPT_ATTRIB_THREAD_CATCHUP_ON_EXIT:
-				SET_INTEGER(thread_catchup_on_exit);
+				SET_BOOLEAN(thread_catchup_on_exit);
 
 			case OPT_ATTRIB_THREAD_FORMAT:
 				SET_STRING(thread_format);
@@ -843,16 +853,16 @@ set_attrib(
 				SET_INTEGER(show_author);
 
 			case OPT_ATTRIB_SHOW_SIGNATURES:
-				SET_INTEGER(show_signatures);
+				SET_BOOLEAN(show_signatures);
 
 			case OPT_ATTRIB_TRIM_ARTICLE_BODY:
 				SET_INTEGER(trim_article_body);
 
 			case OPT_ATTRIB_VERBATIM_HANDLING:
-				SET_INTEGER(verbatim_handling);
+				SET_BOOLEAN(verbatim_handling);
 
 			case OPT_ATTRIB_WRAP_ON_NEXT_UNREAD:
-				SET_INTEGER(wrap_on_next_unread);
+				SET_BOOLEAN(wrap_on_next_unread);
 
 			case OPT_ATTRIB_SORT_ARTICLE_TYPE:
 				SET_INTEGER(sort_article_type);
@@ -870,10 +880,10 @@ set_attrib(
 				SET_STRING(quick_kill_scope);
 
 			case OPT_ATTRIB_QUICK_KILL_EXPIRE:
-				SET_INTEGER(quick_kill_expire);
+				SET_BOOLEAN(quick_kill_expire);
 
 			case OPT_ATTRIB_QUICK_KILL_CASE:
-				SET_INTEGER(quick_kill_case);
+				SET_BOOLEAN(quick_kill_case);
 
 			case OPT_ATTRIB_QUICK_SELECT_HEADER:
 				SET_INTEGER(quick_select_header);
@@ -882,10 +892,10 @@ set_attrib(
 				SET_STRING(quick_select_scope);
 
 			case OPT_ATTRIB_QUICK_SELECT_EXPIRE:
-				SET_INTEGER(quick_select_expire);
+				SET_BOOLEAN(quick_select_expire);
 
 			case OPT_ATTRIB_QUICK_SELECT_CASE:
-				SET_INTEGER(quick_select_case);
+				SET_BOOLEAN(quick_select_case);
 
 			case OPT_ATTRIB_MAILING_LIST:
 				SET_STRING(mailing_list);
@@ -905,7 +915,7 @@ set_attrib(
 				SET_STRING(x_body);
 
 			case OPT_ATTRIB_X_COMMENT_TO:
-				SET_INTEGER(x_comment_to);
+				SET_BOOLEAN(x_comment_to);
 
 			case OPT_ATTRIB_FCC:
 				SET_STRING(fcc);
@@ -920,7 +930,7 @@ set_attrib(
 				SET_STRING(mime_types_to_save);
 
 			case OPT_ATTRIB_MIME_FORWARD:
-				SET_INTEGER(mime_forward);
+				SET_BOOLEAN(mime_forward);
 
 #ifdef HAVE_ISPELL
 			case OPT_ATTRIB_ISPELL:
@@ -928,7 +938,7 @@ set_attrib(
 #endif /* HAVE_ISPELL */
 
 			case OPT_ATTRIB_TEX2ISO_CONV:
-				SET_INTEGER(tex2iso_conv);
+				SET_BOOLEAN(tex2iso_conv);
 
 			default:
 				break;
@@ -1056,7 +1066,6 @@ assign_attributes_to_groups(
 				SET_ATTRIB(ask_for_metamail);
 				SET_ATTRIB(auto_cc_bcc);
 				SET_ATTRIB(auto_list_thread);
-				SET_ATTRIB(auto_save);
 				SET_ATTRIB(auto_select);
 				SET_ATTRIB(batch_save);
 				SET_ATTRIB(delete_tmp_files);
@@ -1211,7 +1220,6 @@ write_attributes_file(
 	fprintf(fp, _("#  auto_cc_bcc=NUM\n"));
 	fprintf(fp, _("#    0=No, 1=Cc, 2=Bcc, 3=Cc and Bcc\n"));
 	fprintf(fp, _("#  auto_list_thread=ON/OFF\n"));
-	fprintf(fp, _("#  auto_save=ON/OFF\n"));
 	fprintf(fp, _("#  auto_select=ON/OFF\n"));
 	fprintf(fp, _("#  batch_save=ON/OFF\n"));
 	fprintf(fp, _("#  date_format=STRING (eg. %%a, %%d %%b %%Y %%H:%%M:%%S)\n"));
@@ -1399,6 +1407,8 @@ write_attributes_file(
 		for (i = 1; i < num_scope; i++) {
 			scope = &scopes[i];
 			if (!scope->global) {
+				if (skip_scope(scope))
+					continue;
 				fprintf(fp, "\nscope=%s\n", scope->scope);
 				if (scope->state->add_posted_to_filter)
 					fprintf(fp, "add_posted_to_filter=%s\n", print_boolean(scope->attribute->add_posted_to_filter));
@@ -1414,8 +1424,6 @@ write_attributes_file(
 					fprintf(fp, "auto_list_thread=%s\n", print_boolean(scope->attribute->auto_list_thread));
 				if (scope->state->auto_select)
 					fprintf(fp, "auto_select=%s\n", print_boolean(scope->attribute->auto_select));
-				if (scope->state->auto_save)
-					fprintf(fp, "auto_save=%s\n", print_boolean(scope->attribute->auto_save));
 				if (scope->state->batch_save)
 					fprintf(fp, "batch_save=%s\n", print_boolean(scope->attribute->batch_save));
 				if (scope->state->date_format && scope->attribute->date_format)
@@ -1579,6 +1587,95 @@ write_attributes_file(
 }
 
 
+/*
+ * Returns true if given scope is empty, i.e. no attribute is set
+ */
+static t_bool
+skip_scope(
+	struct t_scope *scope)
+{
+	return !(scope->state->add_posted_to_filter
+		|| scope->state->advertising
+		|| scope->state->alternative_handling
+		|| scope->state->ask_for_metamail
+		|| scope->state->auto_cc_bcc
+		|| scope->state->auto_list_thread
+		|| scope->state->auto_select
+		|| scope->state->batch_save
+		|| (scope->state->date_format && scope->attribute->date_format)
+		|| scope->state->delete_tmp_files
+		|| (scope->state->editor_format && scope->attribute->editor_format)
+#ifdef HAVE_COLOR
+		|| scope->state->extquote_handling
+#endif /* HAVE_COLOR */
+		|| (scope->state->fcc && scope->attribute->fcc)
+		|| (scope->state->followup_to && scope->attribute->followup_to)
+		|| (scope->state->from && scope->attribute->from)
+		|| scope->state->group_catchup_on_exit
+		|| (scope->state->group_format && scope->attribute->group_format)
+		|| scope->state->mail_8bit_header
+		|| scope->state->mail_mime_encoding
+#ifdef HAVE_ISPELL
+		|| (scope->state->ispell && scope->attribute->ispell)
+#endif /* HAVE_ISPELL */
+		|| (scope->state->maildir && scope->attribute->maildir)
+		|| (scope->state->mailing_list && scope->attribute->mailing_list)
+		|| scope->state->mark_ignore_tags
+		|| scope->state->mark_saved_read
+		|| scope->state->mime_forward
+		|| (scope->state->mime_types_to_save && scope->attribute->mime_types_to_save)
+#ifdef CHARSET_CONVERSION
+		|| scope->state->mm_network_charset
+		|| (scope->state->undeclared_charset && scope->attribute->undeclared_charset)
+#endif /* CHARSET_CONVERSION */
+		|| (scope->state->news_headers_to_display && scope->attribute->news_headers_to_display)
+		|| (scope->state->news_headers_to_not_display && scope->attribute->news_headers_to_not_display)
+		|| (scope->state->news_quote_format && scope->attribute->news_quote_format)
+		|| (scope->state->organization && scope->attribute->organization)
+		|| scope->state->pos_first_unread
+		|| scope->state->post_8bit_header
+		|| scope->state->post_mime_encoding
+		|| scope->state->post_process_view
+		|| scope->state->post_process_type
+#ifndef DISABLE_PRINTING
+		|| scope->state->print_header
+#endif /* !DISABLE_PRINTING */
+		|| scope->state->process_only_unread
+		|| scope->state->prompt_followupto
+		|| (scope->state->quick_kill_scope && scope->attribute->quick_kill_scope)
+		|| scope->state->quick_kill_case
+		|| scope->state->quick_kill_expire
+		|| scope->state->quick_kill_header
+		|| (scope->state->quick_select_scope && scope->attribute->quick_select_scope)
+		|| scope->state->quick_select_case
+		|| scope->state->quick_select_expire
+		|| scope->state->quick_select_header
+		|| (scope->state->quote_chars && scope->attribute->quote_chars)
+		|| (scope->state->savedir && scope->attribute->savedir)
+		|| (scope->state->savefile && scope->attribute->savefile)
+		|| scope->state->show_author
+		|| scope->state->show_only_unread_arts
+		|| scope->state->show_signatures
+		|| scope->state->sigdashes
+		|| (scope->state->sigfile && scope->attribute->sigfile)
+		|| scope->state->signature_repost
+		|| scope->state->sort_article_type
+		|| scope->state->sort_threads_type
+		|| scope->state->start_editor_offset
+		|| scope->state->tex2iso_conv
+		|| scope->state->thread_articles
+		|| scope->state->thread_catchup_on_exit
+		|| (scope->state->thread_format && scope->attribute->thread_format)
+		|| scope->state->thread_perc
+		|| scope->state->trim_article_body
+		|| scope->state->verbatim_handling
+		|| scope->state->wrap_on_next_unread
+		|| (scope->state->x_headers && scope->attribute->x_headers)
+		|| (scope->state->x_body && scope->attribute->x_body)
+		|| scope->state->x_comment_to);
+}
+
+
 #ifdef DEBUG
 #	if 0
 static void
@@ -1650,7 +1747,6 @@ dump_attributes(
 			debug_print_file("ATTRIBUTES", "\tauto_cc_bcc=%d", group->attribute->auto_cc_bcc);
 			debug_print_file("ATTRIBUTES", "\tauto_list_thread=%s", print_boolean(group->attribute->auto_list_thread));
 			debug_print_file("ATTRIBUTES", "\tauto_select=%s", print_boolean(group->attribute->auto_select));
-			debug_print_file("ATTRIBUTES", "\tauto_save=%s", print_boolean(group->attribute->auto_save));
 			debug_print_file("ATTRIBUTES", "\tbatch_save=%s", print_boolean(group->attribute->batch_save));
 			debug_print_file("ATTRIBUTES", "\tdate_format=%s", BlankIfNull(group->attribute->date_format));
 			debug_print_file("ATTRIBUTES", "\tdelete_tmp_files=%s", print_boolean(group->attribute->delete_tmp_files));
@@ -1766,7 +1862,6 @@ dump_scopes(
 			debug_print_file(fname, "\t%sauto_cc_bcc=%d", DEBUG_PRINT_STATE(auto_cc_bcc), scope->attribute->auto_cc_bcc);
 			debug_print_file(fname, "\t%sauto_list_thread=%s", DEBUG_PRINT_STATE(auto_list_thread), print_boolean(scope->attribute->auto_list_thread));
 			debug_print_file(fname, "\t%sauto_select=%s", DEBUG_PRINT_STATE(auto_select), print_boolean(scope->attribute->auto_select));
-			debug_print_file(fname, "\t%sauto_save=%s", DEBUG_PRINT_STATE(auto_save), print_boolean(scope->attribute->auto_save));
 			debug_print_file(fname, "\t%sbatch_save=%s", DEBUG_PRINT_STATE(batch_save), print_boolean(scope->attribute->batch_save));
 			debug_print_file(fname, "\t%sdate_format=%s", DEBUG_PRINT_STATE(date_format), DEBUG_PRINT_STRING(date_format));
 			debug_print_file(fname, "\t%sdelete_tmp_files=%s", DEBUG_PRINT_STATE(delete_tmp_files), print_boolean(scope->attribute->delete_tmp_files));
