@@ -3,7 +3,7 @@
  *  Module    : config.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2020-04-23
+ *  Updated   : 2021-02-23
  *  Notes     : Configuration file routines
  *
  * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
@@ -174,8 +174,12 @@ read_config_file(
 			if (match_boolean(buf, "auto_reconnect=", &tinrc.auto_reconnect))
 				break;
 
-			if (match_boolean(buf, "auto_save=", &tinrc.auto_save))
-				break;
+			if (upgrade && upgrade->file_version < 10318) {
+				t_bool ignore;
+				/* option removed */
+				if (match_boolean(buf, "auto_save=", &ignore))
+					break;
+			}
 
 			break;
 
@@ -441,7 +445,7 @@ read_config_file(
 			if (match_string(buf, "inews_prog=", tinrc.inews_prog, sizeof(tinrc.inews_prog)))
 				break;
 
-			if (match_integer(buf, "interactive_mailer=", &tinrc.interactive_mailer, INTERACTIVE_NONE))
+			if (match_integer(buf, "interactive_mailer=", &tinrc.interactive_mailer, (int) INTERACTIVE_NONE))
 				break;
 
 			break;
@@ -538,7 +542,7 @@ read_config_file(
 #endif /* HAVE_ALARM && SIGALRM */
 
 #ifdef HAVE_UNICODE_NORMALIZATION
-			if (match_integer(buf, "normalization_form=", &tinrc.normalization_form, NORMALIZE_MAX))
+			if (match_integer(buf, "normalization_form=", &tinrc.normalization_form, (int) NORMALIZE_MAX))
 				break;
 #endif /* HAVE_UNICODE_NORMALIZATION */
 
@@ -936,9 +940,6 @@ write_config_file(
 	fprintf(fp, "%s", _(txt_savedir.tinrc));
 	fprintf(fp, "savedir=%s\n\n", tinrc.savedir);
 
-	fprintf(fp, "%s", _(txt_auto_save.tinrc));
-	fprintf(fp, "auto_save=%s\n\n", print_boolean(tinrc.auto_save));
-
 	fprintf(fp, "%s", _(txt_mark_saved_read.tinrc));
 	fprintf(fp, "mark_saved_read=%s\n\n", print_boolean(tinrc.mark_saved_read));
 
@@ -1773,7 +1774,7 @@ ulBuildArgv(
 				tmp++;
 			}
 			i++;
-			new_argv = my_realloc(new_argv, ((i + 1) * sizeof(char *)));
+			new_argv = my_realloc(new_argv, ((size_t) (i + 1) * sizeof(char *)));
 			new_argv[i] = NULL;
 		} else
 			tmp++;
