@@ -3,7 +3,7 @@
  *  Module    : init.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2020-09-28
+ *  Updated   : 2021-02-01
  *  Notes     :
  *
  * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
@@ -142,7 +142,7 @@ t_bool disable_sender;			/* disable generation of Sender: header */
 t_bool list_active;
 t_bool newsrc_active;
 t_bool no_write = FALSE;		/* do not write newsrc on quit (-X cmd-line flag) */
-t_bool post_article_and_exit;		/* quick post of an article then exit(elm like) */
+t_bool post_article_and_exit;		/* quick post of an article then exit (elm like) */
 t_bool post_postponed_and_exit;		/* post postponed articles and exit */
 t_bool range_active;		/* Set if a range is defined */
 t_bool reread_active_for_posted_arts;
@@ -344,7 +344,6 @@ struct t_config tinrc = {
 	0,			/* auto_cc_bcc */
 	TRUE,		/* auto_list_thread */
 	FALSE,		/* auto_reconnect */
-	FALSE,		/* auto_save */
 	TRUE,		/* batch_save */
 	TRUE,		/* beginner_level */
 	FALSE,		/* cache_overview_files */
@@ -477,7 +476,6 @@ struct t_config tinrc = {
 	TRUE,		/* attrib_alternative_handling */
 	TRUE,		/* attrib_auto_list_thread */
 	FALSE,		/* attrib_auto_select */
-	FALSE,		/* attrib_auto_save */
 	TRUE,		/* attrib_batch_save */
 	TRUE,		/* attrib_delete_tmp_files */
 	TRUE,		/* attrib_group_catchup_on_exit */
