@@ -3,10 +3,10 @@
  *  Module    : misc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2020-05-19
+ *  Updated   : 2021-02-23
  *  Notes     :
  *
- * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -286,7 +286,7 @@ copy_body(
 		return;
 	}
 
-	while(maxlen > 0 && *q) {
+	while (maxlen > 0 && *q) {
 		if (*q == '%' && *(q + 1) == 'I') {
 			if (maxlen < ilen) /* not enough space left for %I expansion */
 				break;
@@ -370,8 +370,7 @@ get_val(
 
 /*
  * IMHO it's not tins job to take care about dumb editor backupfiles
- * otherwise BACKUP_FILE_EXT should be configurable via configure
- * or 'M'enu
+ * otherwise BACKUP_FILE_EXT should be configurable via 'M'enu
  */
 #define BACKUP_FILE_EXT ".b"
 t_bool
@@ -850,34 +849,6 @@ invoke_cmd(
 }
 
 
-void
-draw_percent_mark(
-	long cur_num,
-	long max_num)
-{
-	char buf[32]; /* should be big enough */
-	int len;
-
-	if (NOTESLINES <= 0)
-		return;
-
-	if (cur_num <= 0 && max_num <= 0)
-		return;
-
-	clear_message();
-	snprintf(buf, sizeof(buf), "%s(%d%%) [%ld/%ld]", _(txt_more), (int) (cur_num * 100 / max_num), cur_num, max_num);
-	len = strwidth(buf);
-	MoveCursor(cLINES, cCOLS - len - (1 + BLANK_PAGE_COLS));
-#ifdef HAVE_COLOR
-	fcol(tinrc.col_normal);
-#endif /* HAVE_COLOR */
-	StartInverse();
-	my_fputs(buf, stdout);
-	EndInverse();
-	my_flush();
-}
-
-
 /*
  * grab file portion of fullpath
  */
@@ -980,16 +951,16 @@ eat_re(
 	int size_offsets = ARRAY_SIZE(offsets);
 
 	if (!s || !*s)
-		return "<No subject>"; /* also used in art.c:parse_headers() */
+		return "";
 
 	do {
-		data = pcre_exec(strip_re_regex.re, strip_re_regex.extra, s, strlen(s), 0, 0, offsets, size_offsets);
+		data = pcre_exec(strip_re_regex.re, strip_re_regex.extra, s, (int) strlen(s), 0, 0, offsets, size_offsets);
 		if (offsets[0] == 0)
 			s += offsets[1];
 	} while (data >= 0);
 
 	if (eat_was) do {
-		data = pcre_exec(strip_was_regex.re, strip_was_regex.extra, s, strlen(s), 0, 0, offsets, size_offsets);
+		data = pcre_exec(strip_was_regex.re, strip_was_regex.extra, s, (int) strlen(s), 0, 0, offsets, size_offsets);
 		if (offsets[0] > 0)
 			s[offsets[0]] = '\0';
 	} while (data >= 0);
@@ -1240,7 +1211,7 @@ strfquote(
 					tbuf[2] = '\0';
 					break;
 			}
-			i = strlen(tbuf);
+			i = (int) strlen(tbuf);
 			if (i) {
 				if (s + i < endp - 1) {
 					strcpy(s, tbuf);
@@ -1323,7 +1294,7 @@ strfquote(
 					tbuf[2] = '\0';
 					break;
 			}
-			i = strlen(tbuf);
+			i = (int) strlen(tbuf);
 			if (i) {
 				if (s + i < endp - 1) {
 					strcpy(s, tbuf);
@@ -1336,7 +1307,7 @@ strfquote(
 out:
 	if (s < endp && *format == '\0') {
 		*s = '\0';
-		return (s - start);
+		return (int) (s - start);
 	} else
 		return 0;
 }
@@ -1395,7 +1366,7 @@ strfeditor(
 					tbuf[2] = '\0';
 					break;
 			}
-			i = strlen(tbuf);
+			i = (int) strlen(tbuf);
 			if (i) {
 				if (s + i < endp - 1) {
 					strcpy(s, tbuf);
@@ -1434,7 +1405,7 @@ strfeditor(
 					tbuf[2] = '\0';
 					break;
 			}
-			i = strlen(tbuf);
+			i = (int) strlen(tbuf);
 			if (i) {
 				if (s + i < endp - 1) {
 					strcpy(s, tbuf);
@@ -1447,7 +1418,7 @@ strfeditor(
 out:
 	if (s < endp && *format == '\0') {
 		*s = '\0';
-		return (s - start);
+		return (int) (s - start);
 	} else
 		return 0;
 }
@@ -1665,7 +1636,7 @@ _strfpath(
 				if (group != NULL && *format == 'G') {
 					memset(tbuf, 0, sizeof(tbuf));
 					STRCPY(tbuf, group->name);
-					i = strlen(tbuf);
+					i = (int) strlen(tbuf);
 					if (((str + i) < (endp - 1)) && (i > 0)) {
 						strcpy(str, tbuf);
 						str += i;
@@ -1679,7 +1650,7 @@ _strfpath(
 					char *pbuf = my_malloc(strlen(group->name) + 2); /* trailing "/\0" */
 
 					make_group_path(group->name, pbuf);
-					if ((i = strlen(pbuf)))
+					if ((i = (int) strlen(pbuf)))
 						pbuf[i--] = '\0'; /* remove trailing '/' */
 					else {
 						str[0] = '\0';
@@ -1894,7 +1865,7 @@ strfmailer(
 					break;
 			}
 			if (*tbuf) {
-				if (sh_format(dest, endp - dest, "%s", tbuf) >= 0)
+				if (sh_format(dest, (size_t) (endp - dest), "%s", tbuf) >= 0)
 					dest += strlen(dest);
 				else
 					return 0;
@@ -1992,10 +1963,10 @@ strfmailer(
 			if (*tbuf) {
 				if (escaped) {
 					if (endp - dest > 0) {
-						strncpy(dest, tbuf, endp - dest);
+						strncpy(dest, tbuf, (size_t) (endp - dest));
 						dest += strlen(dest);
 					}
-				} else if (sh_format(dest, endp - dest, "%s", tbuf) >= 0) {
+				} else if (sh_format(dest, (size_t) (endp - dest), "%s", tbuf) >= 0) {
 					dest += strlen(dest);
 				} else
 					return 0;
@@ -2005,7 +1976,7 @@ strfmailer(
 out:
 	if (dest < endp && *format == '\0') {
 		*dest = '\0';
-		return (dest - start);
+		return (int) (dest - start);
 	} else
 		return 0;
 }
@@ -2018,7 +1989,7 @@ int
 get_initials(
 	struct t_article *art,
 	char *s,
-	int maxsize) /* return value is always ignored */
+	int maxsize) /* return value is always 0 and ignored */
 {
 	char tbuf[PATH_LEN];
 	int i, j = 0;
@@ -2030,10 +2001,11 @@ get_initials(
 	if (s == NULL || maxsize <= 0)
 		return 0;
 
+	s[0] = '\0';
 	STRCPY(tbuf, ((art->name != NULL) ? art->name : art->from));
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	if ((wtmp = char2wchar_t(tbuf)) != NULL) {
-		wbuf = my_malloc(sizeof(wchar_t) * (maxsize + 1));
+		wbuf = my_malloc(sizeof(wchar_t) * (size_t) (maxsize + 1));
 		for (i = 0; wtmp[i] && j < maxsize; i++) {
 			if (iswalpha((wint_t) wtmp[i])) {
 				if (!iflag) {
@@ -2506,7 +2478,7 @@ buffer_to_local(
 					 */
 					cur_inbuf = inbuf;
 					cur_ibl = inbytesleft;
-					used = outbuf - obuf;
+					used = (int) (outbuf - obuf);
 					cur_obl = outbytesleft;
 
 					errno = 0;
@@ -2973,6 +2945,9 @@ gnksa_dequote_plainphrase(
 	int initialstate;	/* initial state */
 	int state;	/* current state */
 
+	if (!*realname)
+		return GNKSA_MISSING_REALNAME;
+
 	/* initialize state machine */
 	switch (addrtype) {
 		case GNKSA_ADDRTYPE_ROUTE:
@@ -3397,22 +3372,17 @@ gnksa_split_from(
 	*address = *realname = '\0';
 
 	/* copy raw address into work area */
-	strncpy(work, from, HEADER_LEN - 2);
-	work[HEADER_LEN - 2] = '\0';
-	work[HEADER_LEN - 1] = '\0';
+	STRCPY(work, from);
+	strip_line(work);
+	strcpy(address, work);
 
-	/* skip trailing whitespace */
-	addr_end = work + strlen(work) - 1;
-	while (addr_end >= work && (*addr_end == ' ' || *addr_end == '\t'))
-		addr_end--;
-
-	if (addr_end < work) {
+	if (!*work) {
 		*addrtype = GNKSA_ADDRTYPE_OLDSTYLE;
-		return GNKSA_LPAREN_MISSING;
+		return GNKSA_ATSIGN_MISSING; /* GNKSA_LPAREN_MISSING */
 	}
 
-	*(addr_end + 1) = '\0';
-	*(addr_end + 2) = '\0';
+	/* skip trailing whitespace */
+ 	addr_end = work + strlen(work) - 1;
 
 	if (*addr_end == '>') {
 		/* route-address used */
@@ -3426,25 +3396,33 @@ gnksa_split_from(
 		if (*addr_begin != '<') /* syntax error in mail address */
 			return GNKSA_LANGLE_MISSING;
 
-		/* copy route address */
 		*addr_end = *addr_begin = '\0';
+		/* copy route address */
 		strcpy(address, addr_begin + 1);
 
+		/* missing realname */
+		if (addr_begin == work)
+			return GNKSA_MISSING_REALNAME;
+
 		/* get realname part */
 		addr_end = addr_begin - 1;
 		addr_begin = work;
 
 		/* strip surrounding whitespace */
-		while (addr_end >= work && (*addr_end == ' '|| *addr_end == '\t'))
-			addr_end--;
-
+		strip_line(addr_end);
 		while ((*addr_begin == ' ') || (*addr_begin == '\t'))
 			addr_begin++;
 
-		*++addr_end = '\0';
+#if 0	/* whitespace only realname */
+		strip_line(addr_begin);
+		if (!strlen(addr_begin))
+			return GNKSA_WHITESPACE_REALNAME;
+		else
+#endif /* 0 */
 		/* copy realname */
 		strcpy(realname, addr_begin);
 	} else {
+		size_t l;
 		/* old-style address used */
 		*addrtype = GNKSA_ADDRTYPE_OLDSTYLE;
 
@@ -3454,22 +3432,32 @@ gnksa_split_from(
 		while ((*addr_begin == ' ') || (*addr_begin == '\t'))
 			addr_begin++;
 
+		if (*addr_begin == '<') {
+			*addrtype = GNKSA_ADDRTYPE_ROUTE;
+			return GNKSA_RANGLE_MISSING;
+		}
+
 		/* scan forward to next whitespace or null */
+		l = strlen(addr_begin);
 		addr_end = addr_begin;
+
 		while ((*addr_end != ' ') && (*addr_end != '\t') && (*addr_end))
 			addr_end++;
 
 		*addr_end = '\0';
+
+		if (l == strlen(addr_begin))
+			return GNKSA_MISSING_REALNAME;
+
 		/* copy route address */
 		strcpy(address, addr_begin);
 
 		/* get realname part */
 		addr_begin = addr_end + 1;
-		addr_end = addr_begin + strlen(addr_begin) -1;
-		/* strip surrounding whitespace */
-		while ((*addr_end == ' ') || (*addr_end == '\t'))
-			addr_end--;
+		addr_end = addr_begin + strlen(addr_begin) - 1;
 
+		/* strip surrounding whitespace */
+		strip_line(addr_end);
 		while ((*addr_begin == ' ') || (*addr_begin == '\t'))
 			addr_begin++;
 
@@ -3627,12 +3615,19 @@ char *
 strip_line(
 	char *line)
 {
-	char *ptr = line + strlen(line) - 1;
+	char *ptr;
 
-	while ((ptr >= line) && (*ptr == ' ' || *ptr == '\t' || *ptr == '\r' || *ptr == '\n'))
+	if (!*line)
+		return line;
+
+	ptr = line + strlen(line);
+	do {
 		ptr--;
-
-	*++ptr = '\0';
+		if (*ptr == ' ' || *ptr == '\t' || *ptr == '\r' || *ptr == '\n')
+			*ptr = '\0';
+		else
+			break;
+	} while (ptr > line);
 
 	return line;
 }
@@ -3680,12 +3675,12 @@ utf8_valid(
 
 		if (c + numc > line + strlen(line)) { /* sequence runs past end of string */
 			illegal = TRUE;
-			numc = line + strlen(line) - c;
+			numc = (int) (line + strlen(line) - c);
 		}
 
 		if (!illegal) {
-			d = *c;
-			e = *(c + 1);
+			d = (unsigned char)*c;
+			e = (unsigned char) *(c + 1);
 
 			switch (numc) {
 				case 2:
@@ -3695,7 +3690,7 @@ utf8_valid(
 					break;
 
 				case 3:
-					f = *(c + 2);
+					f = (unsigned char) *(c + 2);
 					/* out of range or sequences which would also fit into 2 bytes */
 					if (d < 0xe0 || d > 0xef || (d == 0xe0 && e < 0xa0))
 						illegal = TRUE;
@@ -3711,8 +3706,8 @@ utf8_valid(
 					break;
 
 				case 4:
-					f = *(c + 2);
-					g = *(c + 3);
+					f = (unsigned char) *(c + 2);
+					g = (unsigned char) *(c + 3);
 					/* out of range or sequences which would also fit into 3 bytes */
 					if (d < 0xf0 || d > 0xf7 || (d == 0xf0 && e < 0x90))
 						illegal = TRUE;
@@ -3760,7 +3755,7 @@ utf8_valid(
 		}
 
 		for (d = 1; d < numc && !illegal; d++) {
-			e = *(c + d);
+			e = (unsigned char) *(c + d);
 			if (e < 0x80 || e > 0xbf || e == '\0' || e == '\n')
 				illegal = TRUE;
 		}
@@ -3793,7 +3788,7 @@ idna_decode(
 		return out;
 
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-/* IDNA 2008 */
+	/* IDNA 2008 */
 #	if defined(HAVE_LIBIDNKIT) && defined(HAVE_IDN_DECODENAME)
 	{
 		idn_result_t res;
@@ -3801,8 +3796,12 @@ idna_decode(
 
 		if ((q = strrchr(out, '@'))) {
 			q++;
-			r = strrchr(in, '@');
-			r++;
+			if ((r = strrchr(in, '@')))
+				r++;
+			else { /* just to make static analyzer happy */
+				r = in;
+				q = out;
+			}
 		} else {
 			r = in;
 			q = out;
@@ -3820,7 +3819,7 @@ idna_decode(
 	}
 #	endif /* HAVE_LIBIDNKIT && HAVE_IDN_DECODENAME */
 
-/* IDNA 2003 */
+	/* IDNA 2003 */
 #	ifdef HAVE_LIBICUUC
 	{
 		UChar *src;
