@@ -3,7 +3,7 @@
  *  Module    : page.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2019-07-10
+ *  Updated   : 2021-02-25
  *  Notes     :
  *
  * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
@@ -107,6 +107,7 @@ static t_function url_left(void);
 static t_function url_right(void);
 static void build_url_line(int i);
 static void draw_page_header(const char *group);
+static void draw_percent_mark(long cur_num, long max_num);
 static void draw_url_arrow(void);
 static void free_url_list(void);
 static void preprocess_info_message(FILE *info_fh);
@@ -312,7 +313,7 @@ show_page(
 	int i, j, n = 0;
 	int art_type = GROUP_TYPE_NEWS;
 	int hide_uue_tmp;
-	t_artnum old_artnum = T_ARTNUM_CONST(0);
+	t_artnum old_artnum;
 	t_bool mouse_click_on = TRUE;
 	t_bool repeat_search;
 	t_function func;
@@ -331,7 +332,7 @@ show_page(
 		return i;
 
 	if (srch_lineno != -1)
-		process_search(&curr_line, artlines, ARTLINES, PAGE_LEVEL);
+		process_search(&curr_line, (size_t) artlines, (size_t) ARTLINES, PAGE_LEVEL);
 
 	forever {
 		if ((func = handle_keypad(page_left, page_right, page_mouse_action, page_keys)) == GLOBAL_SEARCH_REPEAT) {
@@ -583,7 +584,7 @@ page_goto_next_unread:
 					reveal_ctrl_l_lines = curr_line + ARTLINES - 1;
 					draw_page(group->name, 0);
 				}
-				process_search(&curr_line, artlines, ARTLINES, PAGE_LEVEL);
+				process_search(&curr_line, (size_t) artlines, (size_t) ARTLINES, PAGE_LEVEL);
 				break;
 
 			case GLOBAL_SEARCH_BODY:	/* article body search */
@@ -593,7 +594,7 @@ page_goto_next_unread:
 						XFACE_CLEAR();
 						return i;
 					}
-					process_search(&curr_line, artlines, ARTLINES, PAGE_LEVEL);
+					process_search(&curr_line, (size_t) artlines, (size_t) ARTLINES, PAGE_LEVEL);
 				}
 				break;
 
@@ -601,7 +602,7 @@ page_goto_next_unread:
 				if (arts[this_resp].prev >= 0) {
 					if ((n = which_thread(this_resp)) >= 0 && base[n] != this_resp) {
 						assert(n < grpmenu.max);
-						if ((i = load_article(base[n], group)) < 0) {
+						if ((i = load_article((int) base[n], group)) < 0) {
 							XFACE_CLEAR();
 							return i;
 						}
@@ -651,7 +652,7 @@ page_goto_next_unread:
 				toggle_raw(group);
 				break;
 
-			case PAGE_TOGGLE_TEX2ISO:		/* toggle german TeX to ISO latin1 style conversion */
+			case PAGE_TOGGLE_TEX2ISO:		/* toggle German TeX to ISO latin1 style conversion */
 				if (((group->attribute->tex2iso_conv) = !(group->attribute->tex2iso_conv)))
 					pgart.tex2iso = is_art_tex_encoded(pgart.raw);
 				else
@@ -955,9 +956,11 @@ return_to_index:
 
 			case GLOBAL_DISPLAY_POST_HISTORY:	/* display messages posted by user */
 				XFACE_SUPPRESS();
-				if (user_posted_messages())
-					draw_page(group->name, 0);
-				XFACE_SHOW();
+				if (post_hist_page())
+					return GRP_EXIT;
+				else {
+					XFACE_SHOW();
+				}
 				break;
 
 			case MARK_ARTICLE_UNREAD:	/* mark article as unread(to return) */
@@ -1022,7 +1025,7 @@ return_to_index:
 				break;
 
 			default:
-				info_message(_(txt_bad_command), printascii(key, func_to_key(GLOBAL_HELP, page_keys)));
+				info_message(_(txt_bad_command), PrintFuncKey(key, GLOBAL_HELP, page_keys));
 		}
 	}
 	/* NOTREACHED */
@@ -1079,7 +1082,7 @@ print_message_page(
 		 * determine the correct position to truncate the line
 		 */
 		if ((help_level != INFO_PAGER) && (base_line + i < messagelines - 1)) {	/* not last line of message */
-			bytes = (curr + 1)->offset - curr->offset;
+			bytes = (int) ((curr + 1)->offset - curr->offset);
 			line[bytes] = '\0';
 		}
 
@@ -1089,19 +1092,19 @@ print_message_page(
 		if ((rotate != 0) && ((curr->flags & (C_BODY | C_SIG)) || show_raw_article)) {
 			for (p = line; *p; p++) {
 				if (*p >= 'A' && *p <= 'Z')
-					*p = (*p - 'A' + rotate) % 26 + 'A';
+					*p = (char) ((*p - 'A' + rotate) % 26 + 'A');
 				else if (*p >= 'a' && *p <= 'z')
-					*p = (*p - 'a' + rotate) % 26 + 'a';
+					*p = (char) ((*p - 'a' + rotate) % 26 + 'a');
 			}
 		}
 
 		strip_line(line);
 
 #ifndef USE_CURSES
-		snprintf(screen[i + scroll_region_top].col, cCOLS, "%s" cCRLF, line);
+		snprintf(screen[i + (size_t) scroll_region_top].col, (size_t) cCOLS, "%s" cCRLF, line);
 #endif /* !USE_CURSES */
 
-		MoveCursor(i + scroll_region_top, 0);
+		MoveCursor((int) (i + (size_t) scroll_region_top), 0);
 		draw_pager_line(line, curr->flags, show_raw_article);
 
 		/*
@@ -1110,23 +1113,23 @@ print_message_page(
 		if (tinrc.url_highlight) {
 			if (curr->flags & C_URL)
 #ifdef HAVE_COLOR
-				highlight_regexes(i + scroll_region_top, &url_regex, use_color ? tinrc.col_urls : -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &url_regex, use_color ? tinrc.col_urls : -1);
 #else
-				highlight_regexes(i + scroll_region_top, &url_regex, -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &url_regex, -1);
 #endif /* HAVE_COLOR */
 
 			if (curr->flags & C_MAIL)
 #ifdef HAVE_COLOR
-				highlight_regexes(i + scroll_region_top, &mail_regex, use_color ? tinrc.col_urls : -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &mail_regex, use_color ? tinrc.col_urls : -1);
 #else
-				highlight_regexes(i + scroll_region_top, &mail_regex, -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &mail_regex, -1);
 #endif /* HAVE_COLOR */
 
 			if (curr->flags & C_NEWS)
 #ifdef HAVE_COLOR
-				highlight_regexes(i + scroll_region_top, &news_regex, use_color ? tinrc.col_urls : -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &news_regex, use_color ? tinrc.col_urls : -1);
 #else
-				highlight_regexes(i + scroll_region_top, &news_regex, -1);
+				highlight_regexes((int) (i + (size_t) scroll_region_top), &news_regex, -1);
 #endif /* HAVE_COLOR */
 		}
 
@@ -1135,15 +1138,15 @@ print_message_page(
 		 */
 		if (word_highlight && (curr->flags & C_BODY) && !(curr->flags & C_CTRLL)) {
 #ifdef HAVE_COLOR
-			highlight_regexes(i + scroll_region_top, &slashes_regex, use_color ? tinrc.col_markslash : tinrc.mono_markslash);
-			highlight_regexes(i + scroll_region_top, &stars_regex, use_color ? tinrc.col_markstar : tinrc.mono_markstar);
-			highlight_regexes(i + scroll_region_top, &underscores_regex, use_color ? tinrc.col_markdash : tinrc.mono_markdash);
-			highlight_regexes(i + scroll_region_top, &strokes_regex, use_color ? tinrc.col_markstroke : tinrc.mono_markstroke);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &slashes_regex, use_color ? tinrc.col_markslash : tinrc.mono_markslash);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &stars_regex, use_color ? tinrc.col_markstar : tinrc.mono_markstar);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &underscores_regex, use_color ? tinrc.col_markdash : tinrc.mono_markdash);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &strokes_regex, use_color ? tinrc.col_markstroke : tinrc.mono_markstroke);
 #else
-			highlight_regexes(i + scroll_region_top, &slashes_regex, tinrc.mono_markslash);
-			highlight_regexes(i + scroll_region_top, &stars_regex, tinrc.mono_markstar);
-			highlight_regexes(i + scroll_region_top, &underscores_regex, tinrc.mono_markdash);
-			highlight_regexes(i + scroll_region_top, &strokes_regex, tinrc.mono_markstroke);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &slashes_regex, tinrc.mono_markslash);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &stars_regex, tinrc.mono_markstar);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &underscores_regex, tinrc.mono_markdash);
+			highlight_regexes((int) (i + (size_t) scroll_region_top), &strokes_regex, tinrc.mono_markstroke);
 #endif /* HAVE_COLOR */
 		}
 
@@ -1215,7 +1218,7 @@ draw_page(
 	} else
 		MoveCursor(0, 0);
 
-	print_message_page(note_fp, artline, artlines, curr_line, start, end, PAGE_LEVEL);
+	print_message_page(note_fp, artline, (size_t) artlines, (size_t) curr_line, (size_t) start, (size_t) end, PAGE_LEVEL);
 
 	/*
 	 * Print an appropriate footer
@@ -1336,7 +1339,10 @@ draw_page_header(
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	whichresp = which_response(this_resp);
-	x_resp = num_of_responses(which_thread(this_resp));
+	if ((i = which_thread(this_resp)) >= 0)
+		x_resp = num_of_responses(i);
+	else
+		x_resp = 0;
 
 	line_len = LEN + 1;
 	buf = my_malloc(line_len);
@@ -1957,10 +1963,10 @@ process_search(
 	 * Reposition within article if needed, try to get matched line
 	 * in the middle of the screen
 	 */
-	if (i < *lcurr_line || i >= (int) (*lcurr_line + screen_lines)) {
-		*lcurr_line = i - (screen_lines / 2);
-		if (*lcurr_line + screen_lines > message_lines)	/* off the end */
-			*lcurr_line = message_lines - screen_lines;
+	if (i < *lcurr_line || i >= (int) ((size_t) *lcurr_line + screen_lines)) {
+		*lcurr_line = (int) ((size_t) i - (screen_lines / 2));
+		if (((size_t) *lcurr_line + screen_lines) > message_lines)	/* off the end */
+			*lcurr_line = (int) (message_lines - screen_lines);
 		/* else pos. is just fine */
 	}
 
@@ -2010,7 +2016,7 @@ toggle_raw(
 
 			j = 0;
 			rewind(pgart.raw);
-			pgart.rawl = my_malloc(sizeof(t_lineinfo) * chunk);
+			pgart.rawl = my_malloc(sizeof(t_lineinfo) * (size_t) chunk);
 			offset = ftell(pgart.raw);
 
 			while ((line = tin_fgets(pgart.raw, FALSE)) != NULL) {
@@ -2025,7 +2031,7 @@ toggle_raw(
 				j++;
 				if (j >= chunk) {
 					chunk += 50;
-					pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * chunk);
+					pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * (size_t) chunk);
 				}
 
 				p = line;
@@ -2035,7 +2041,7 @@ toggle_raw(
 					while ((space > 0) && *p) {
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 						num_bytes = mbtowc(&wc, p, MB_CUR_MAX);
-						if (num_bytes != -1 && iswprint(wc)) {
+						if (num_bytes != -1 && iswprint((wint_t) wc)) {
 							if ((space -= wcwidth(wc)) < 0)
 								break;
 							p += num_bytes;
@@ -2079,7 +2085,7 @@ toggle_raw(
 						pgart.rawl[j].flags = 0;
 						if (++j >= chunk) {
 							chunk += 50;
-							pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * chunk);
+							pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * (size_t) chunk);
 						}
 					}
 				}
@@ -2091,7 +2097,7 @@ toggle_raw(
 				offset = ftell(pgart.raw);
 			}
 
-			pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * j);
+			pgart.rawl = my_realloc(pgart.rawl, sizeof(t_lineinfo) * (size_t) j);
 		}
 		artline = pgart.rawl;
 		artlines = j;
@@ -2132,7 +2138,7 @@ void
 info_pager(
 	FILE *info_fh,
 	const char *title,
-	t_bool wrap_at_ends)
+	t_bool wrap_at_ends)	/* currently always TRUE */
 {
 	int offset;
 	t_function func;
@@ -2256,7 +2262,7 @@ info_pager(
 				if ((search_article((func == GLOBAL_SEARCH_SUBJECT_FORWARD), (func == GLOBAL_SEARCH_REPEAT), search_line, num_info_lines, infoline, num_info_lines - 1, info_file)) == -1)
 					break;
 
-				process_search(&curr_info_line, num_info_lines, NOTESLINES, INFO_PAGER);
+				process_search(&curr_info_line, (size_t) num_info_lines, (size_t) NOTESLINES, INFO_PAGER);
 				break;
 
 			case GLOBAL_QUIT:	/* quit */
@@ -2309,7 +2315,7 @@ display_info_page(
 		center_line(0, TRUE, info_title);
 	}
 
-	print_message_page(info_file, infoline, num_info_lines, curr_info_line, start, end, INFO_PAGER);
+	print_message_page(info_file, infoline, (size_t) num_info_lines, (size_t) curr_info_line, (size_t) start, (size_t) end, INFO_PAGER);
 
 	/* print footer */
 	draw_percent_mark(curr_info_line + (curr_info_line + NOTESLINES < num_info_lines ? NOTESLINES : num_info_lines - curr_info_line), num_info_lines);
@@ -2328,7 +2334,7 @@ preprocess_info_message(
 		return;
 
 	rewind(info_fh);
-	infoline = my_malloc(sizeof(t_lineinfo) * chunk);
+	infoline = my_malloc(sizeof(t_lineinfo) * (size_t) chunk);
 	num_info_lines = 0;
 
 	do {
@@ -2337,12 +2343,12 @@ preprocess_info_message(
 		num_info_lines++;
 		if (num_info_lines >= chunk) {
 			chunk += 50;
-			infoline = my_realloc(infoline, sizeof(t_lineinfo) * chunk);
+			infoline = my_realloc(infoline, sizeof(t_lineinfo) * (size_t) chunk);
 		}
 	} while (tin_fgets(info_fh, FALSE) != NULL);
 
 	num_info_lines--;
-	infoline = my_realloc(infoline, sizeof(t_lineinfo) * num_info_lines);
+	infoline = my_realloc(infoline, sizeof(t_lineinfo) * (size_t) num_info_lines);
 }
 
 
@@ -2513,7 +2519,7 @@ url_page(
 				break;
 
 			default:
-				info_message(_(txt_bad_command), printascii(key, func_to_key(GLOBAL_HELP, url_keys)));
+				info_message(_(txt_bad_command), PrintFuncKey(key, GLOBAL_HELP, url_keys));
 				break;
 		}
 	}
@@ -2568,7 +2574,7 @@ build_url_line(
 #endif /* USE_CURSES */
 
 	lptr = find_url(i);
-	snprintf(sptr, cCOLS, "  %s  %-*.*s%s", tin_ltoa(i + 1, 4), len, len, lptr->url, cCRLF);
+	snprintf(sptr, (size_t) cCOLS, "  %s  %-*.*s%s", tin_ltoa(i + 1, 4), len, len, lptr->url, cCRLF);
 	WriteLine(INDEX2LNUM(i), sptr);
 
 #ifdef USE_CURSES
@@ -2588,7 +2594,7 @@ process_url(
 	lptr = find_url(n);
 	len = strlen(lptr->url) << 1; /* double size; room for editing URL */
 	url = my_malloc(len + 1);
-	if (prompt_default_string("URL:", url, len, lptr->url, HIST_URL)) {
+	if (prompt_default_string("URL:", url, (int) len, lptr->url, HIST_URL)) {
 		if (!*url) {			/* Don't try and open nothing */
 			free(url);
 			return FALSE;
@@ -2635,9 +2641,9 @@ build_url_list(
 		 */
 		forever {
 			/* any matches left? */
-			if (pcre_exec(url_regex.re, url_regex.extra, ptr, strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
-				if (pcre_exec(mail_regex.re, mail_regex.extra, ptr, strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
-					if (pcre_exec(news_regex.re, news_regex.extra, ptr, strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
+			if (pcre_exec(url_regex.re, url_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
+				if (pcre_exec(mail_regex.re, mail_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
+					if (pcre_exec(news_regex.re, news_regex.extra, ptr, (int) strlen(ptr), 0, 0, offsets, offsets_size) == PCRE_ERROR_NOMATCH)
 						break;
 
 			*(ptr + offsets[1]) = '\0';
@@ -2672,3 +2678,31 @@ free_url_list(
 	}
 	url_list = NULL;
 }
+
+
+static void
+draw_percent_mark(
+	long cur_num,
+	long max_num)
+{
+	char buf[32]; /* FIXME: may get truncated with long localized _(txt_more) ... */
+	int len;
+
+	if (NOTESLINES <= 0)
+		return;
+
+	if (cur_num <= 0 && max_num <= 0)
+		return;
+
+	clear_message();
+	snprintf(buf, sizeof(buf), "%s(%d%%) [%ld/%ld]", _(txt_more), (int) (cur_num * 100 / max_num), cur_num, max_num);
+	len = strwidth(buf);
+	MoveCursor(cLINES, cCOLS - len - (1 + BLANK_PAGE_COLS));
+#ifdef HAVE_COLOR
+	fcol(tinrc.col_normal);
+#endif /* HAVE_COLOR */
+	StartInverse();
+	my_fputs(buf, stdout);
+	EndInverse();
+	my_flush();
+}
