@@ -3,12 +3,12 @@
  *  Module    : refs.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 1996-05-09
- *  Updated   : 2020-05-13
+ *  Updated   : 2021-02-23
  *  Notes     : Caching of message ids / References based threading
  *  Credits   : Richard Hodson <richard@macgyver.tele2.co.uk>
  *              hash_msgid, free_msgid
  *
- * Copyright (c) 1996-2020 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 1996-2021 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -115,7 +115,7 @@ hash_msgid(
 	unsigned int hash = 0;
 
 	while (*key && *key != '@') {
-		hash = (hash << 1) ^ *key;
+		hash = (hash << 1) ^ (unsigned) *key;
 		++key;
 	}
 
@@ -592,7 +592,7 @@ dump_thread(
 	/*
 	 * Dump the current article
 	 */
-	sprintf(ptr, "%3d %*s", msgid->article, 2*level, "  ");
+	sprintf(ptr, "%3d %*s", msgid->article, 2 * level, "  ");
 
 	len = strlen(ptr);
 	i = cCOLS - len - 20;
@@ -939,13 +939,7 @@ collate_subjects(
 			 * is that we have to add later threads onto the end of the
 			 * previous thread
 			 */
-#if 1
-			if (arts[i].subject == arts[j].subject)
-#else
-			/* see also art.c:thread_by_subject() */
-			if ((arts[i].subject == arts[j].subject) || (arts[i].archive && arts[j].archive && (arts[i].archive->name == arts[j].archive->name)))
-#endif /* 1 */
-			{
+			if (arts[i].subject == arts[j].subject) {
 				/* DEBUG_PRINT((dbgfd, "RES: %d is now previous, at end of %d\n", i, j)); */
 				for (art = j; arts[art].thread >= 0; art = arts[art].thread)
 					;
