@@ -3,7 +3,7 @@
  *  Module    : rfc2046.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 2000-02-18
- *  Updated   : 2020-12-17
+ *  Updated   : 2021-02-23
  *  Notes     : RFC 2046 MIME article parsing
  *
  * Copyright (c) 2000-2021 Jason Faultless <jason@altarstone.com>
@@ -160,7 +160,7 @@ boundary_cmp(
 
 	nl = l[len - 1] == '\n';
 
-	if (len != blen + 2 + nl && len != blen + 4 + nl) {
+	if (len != blen + 2 + (size_t) nl && len != blen + 4 + (size_t) nl) {
 		free(l);
 		return BOUND_NONE;
 	}
@@ -388,7 +388,7 @@ decode_value(
 
 	while (*rptr) {
 		if (*rptr == '%' && IS_XDIGIT(*(rptr + 1)) && IS_XDIGIT(*(rptr + 2))) {
-			*wptr++ = XVAL(*(rptr + 1)) << 4 | XVAL(*(rptr + 2));
+			*wptr++ = (char) (XVAL(*(rptr + 1)) << 4 | XVAL(*(rptr + 2)));
 			rptr += 3;
 		} else
 			*wptr++ = *rptr++;
@@ -992,6 +992,11 @@ parse_rfc822_headers(
 		if (line[0] == '\0') {
 			if (to)
 				hdr->ext->offset = ftell(to);	/* Offset of main body */
+
+			/* avoid null subject */
+			if (!hdr->subj)
+				hdr->subj = my_strdup("");
+
 			return 0;
 		}
 
@@ -1178,6 +1183,7 @@ parse_multipart_article(
 {
 	char *line;
 	char *ptr;
+	const char *bd;
 	int bnd;
 	int state = M_SEARCHING;
 	t_bool is_rfc822 = FALSE;
@@ -1216,8 +1222,10 @@ parse_multipart_article(
 			 * When we have reached the end boundary of the outermost envelope
 			 * just log any trailing data for the raw article format.
 			 */
-			if (boundary_cmp(line, get_param(artinfo->hdr.ext->params, "boundary")) == BOUND_END)
-				depth = 0;
+			if ((bd = get_param(artinfo->hdr.ext->params, "boundary")) != NULL) {
+				if (boundary_cmp(line, bd) == BOUND_END)
+					depth = 0;
+			}
 #if 0 /* doesn't count tailing lines after envelop mime part - correct but confusing */
 			if (read_news_via_nntp && depth == 0)
 				while ((line = tin_fgets(infile, FALSE)) != NULL)
@@ -1460,7 +1468,7 @@ parse_rfc2045_article(
 		goto error;
 
 	/* no article data returned, just a '.' after 220er response */
-	if (ret == 0 && artinfo->hdr.ext->offset == 0) {
+	if (artinfo->hdr.ext->offset == 0) {
 		ret = ART_UNAVAILABLE;
 		goto error;
 	}
@@ -1546,7 +1554,7 @@ open_art_fp(
 /* ------------------------for accessing articles ------------------- */
 
 /*
- * Open's and postprocesses and article
+ * Opens and postprocesses an article
  * Populates the passed in artinfo structure if successful
  *
  * Returns:
