@@ -3,10 +3,10 @@
  *  Module    : screen.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2020-05-21
+ *  Updated   : 2021-02-23
  *  Notes     :
  *
- * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -260,11 +260,22 @@ center_line(
 	t_bool inverse,
 	const char *str)
 {
+	char *ln;
 	int pos;
 	int len;
 
 	len = strwidth(str);
 
+#if defined(HAVE_LIBICUUC) && defined(MULTIBYTE_ABLE) && defined(HAVE_UNICODE_UBIDI_H) && !defined(NO_LOCALE)
+	if (tinrc.render_bidi && IS_LOCAL_CHARSET("UTF-8") && len > 1) {
+		t_bool is_rtl;
+
+		if ((ln = render_bidi(str, &is_rtl)) == NULL)
+			ln = my_strdup(str);
+	} else
+#endif /* HAVE_LIBICUUC && MULTIBYTE_ABLE && HAVE_UNICODE_UBIDI_H && !NO_LOCALE */
+		ln = my_strdup(str);
+
 	if (!cmd_line) {
 		if (cCOLS >= len)
 			pos = (cCOLS - len) / 2;
@@ -281,11 +292,11 @@ center_line(
 	if (len >= cCOLS) {
 		char *buffer;
 
-		buffer = strunc(str, cCOLS - 2);
+		buffer = strunc(ln, cCOLS - 2);
 		my_fputs(buffer, stdout);
 		free(buffer);
 	} else
-		my_fputs(str, stdout);
+		my_fputs(ln, stdout);
 
 	if (cmd_line)
 		my_flush();
@@ -293,6 +304,7 @@ center_line(
 		if (inverse)
 			EndInverse();
 	}
+	free(ln);
 }
 
 
@@ -534,8 +546,8 @@ show_progress(
 	} else {
 		/* Get the current time */
 		tin_gettime(&this_time);
-		time_diff = (this_time.tv_sec - last_time.tv_sec) * 1000000;
-		time_diff += ((this_time.tv_nsec - last_time.tv_nsec) / 1000);
+		time_diff = (int) ((this_time.tv_sec - last_time.tv_sec) * 1000000);
+		time_diff = (int) (time_diff + ((this_time.tv_nsec - last_time.tv_nsec) / 1000));
 		count_diff = (count - last_count);
 
 		if (!count_diff) /* avoid div by zero */
@@ -553,17 +565,17 @@ show_progress(
 		 */
 		if (samples == 20) {
 			sum -= average;
-			sum += (time_diff / count_diff);
+			sum = (int) (sum + (time_diff / count_diff));
 			average = sum / 20;
 		} else {
-			sum += (time_diff / count_diff);
+			sum = (int) (sum + (time_diff / count_diff));
 			average = sum / ++samples;
 		}
 
 		if (average >= 1000000)
-			secs_left = (total - count) * (average / 1000000);
+			secs_left = (int) ((total - count) * (average / 1000000));
 		else
-			secs_left = ((total - count) * average) / 1000000;
+			secs_left = (int) (((total - count) * average) / 1000000);
 
 		if (secs_left < 0)
 			secs_left = 0;
