@@ -3,7 +3,7 @@
  *  Module    : string.c
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   : 1997-01-20
- *  Updated   : 2020-05-31
+ *  Updated   : 2021-02-23
  *  Notes     :
  *
  * Copyright (c) 1997-2021 Urs Janssen <urs@tin.org>
@@ -666,7 +666,7 @@ expand_tab(
 
 #define SH_FORMAT(c)	if (++result >= (int) len) \
 				break; \
-			*dst++ = c
+			*dst++ = (char) c
 
 #define SH_SINGLE "\\\'"
 #define SH_DOUBLE "\\\'\"`$"
@@ -837,7 +837,7 @@ char2wchar_t(
 		return NULL;
 	}
 
-	wstr = my_malloc(sizeof(wchar_t) * (len + 1));
+	wstr = my_calloc(1, sizeof(wchar_t) * (len + 1));
 	mbstowcs(wstr, test, len + 1);
 	free(test);
 
@@ -917,7 +917,7 @@ wcspart(
 
 		gap = columns - wcswidth(wbuf, wcslen(wbuf) + 1);
 		assert(gap >= 0);
-		wbuf = my_realloc(wbuf, sizeof(wchar_t) * (wcslen(wbuf) + gap + 1));
+		wbuf = my_realloc(wbuf, sizeof(wchar_t) * (wcslen(wbuf) + (size_t) gap + 1));
 		ptr = wbuf + wcslen(wbuf); /* set ptr again to end of wbuf */
 
 		while (gap-- > 0)
@@ -1098,7 +1098,7 @@ strunc(
 		tmp = my_strdup(message);
 	else {
 		tmp = my_malloc(len + 1);
-		snprintf(tmp, len + 1, "%-.*s%s", len - 3, message, TRUNC_TAIL);
+		snprintf(tmp, (size_t) (len + 1), "%-.*s%s", len - 3, message, TRUNC_TAIL);
 	}
 
 	return tmp;
@@ -1134,7 +1134,7 @@ wstrunc(
 			tail = char2wchar_t(TRUNC_TAIL);
 
 		len_tail = tail ? wcslen(tail) : 0;
-		wtmp2 = wcspart(wtmp, len - len_tail, FALSE);
+		wtmp2 = wcspart(wtmp, (int) ((size_t) len - len_tail), FALSE);
 		free(wtmp);
 		wtmp = my_realloc(wtmp2, sizeof(wchar_t) * (wcslen(wtmp2) + len_tail + 1));	/* wtmp2 isn't valid anymore and doesn't have to be free()ed */
 		if (!tail)
@@ -1245,8 +1245,8 @@ normalize(
 		UChar *ustr, *norm;
 		UErrorCode status = U_ZERO_ERROR;
 #ifdef HAVE_UNICODE_UNORM2_H
-		static const char *uname[] = {"nfc", "nfkc", "nfkc_cf"}; /* */
-		const char *unamep;
+		static const char *uni_name[] = {"nfc", "nfkc", "nfkc_cf"}; /* */
+		const char *uni_namep;
 		UNormalization2Mode mode;
 #else
 		UNormalizationMode mode;
@@ -1259,7 +1259,7 @@ normalize(
 		switch (tinrc.normalization_form) {
 			case NORMALIZE_NFD:
 #ifdef HAVE_UNICODE_UNORM2_H
-				unamep = uname[0];
+				uni_namep = uni_name[0];
 				mode = UNORM2_DECOMPOSE;
 #else
 				mode = UNORM_NFD;
@@ -1268,7 +1268,7 @@ normalize(
 
 			case NORMALIZE_NFC:
 #ifdef HAVE_UNICODE_UNORM2_H
-				unamep = uname[0];
+				uni_namep = uni_name[0];
 				mode = UNORM2_COMPOSE;
 #else
 				mode = UNORM_NFC;
@@ -1277,7 +1277,7 @@ normalize(
 
 			case NORMALIZE_NFKD:
 #ifdef HAVE_UNICODE_UNORM2_H
-				unamep = uname[1];
+				uni_namep = uni_name[1];
 				mode = UNORM2_DECOMPOSE;
 #else
 				mode = UNORM_NFKD;
@@ -1285,7 +1285,7 @@ normalize(
 				break;
 #ifdef HAVE_UNICODE_UNORM2_H
 			case NORMALIZE_NFKC_CF:
-				unamep = uname[2];
+				uni_namep = uni_name[2];
 				mode = UNORM2_COMPOSE;
 				break;
 #endif /* HAVE_UNICODE_UNORM2_H */
@@ -1293,7 +1293,7 @@ normalize(
 			case NORMALIZE_NFKC:
 			default:
 #ifdef HAVE_UNICODE_UNORM2_H
-				unamep = uname[1];
+				uni_namep = uni_name[1];
 				mode = UNORM2_COMPOSE;
 #else
 				mode = UNORM_NFKC;
@@ -1301,7 +1301,7 @@ normalize(
 		}
 
 #ifdef HAVE_UNICODE_UNORM2_H
-		needed = unorm2_normalize(unorm2_getInstance(NULL, unamep, mode, &status), ustr, -1, NULL, 0, &status);
+		needed = unorm2_normalize(unorm2_getInstance(NULL, uni_namep, mode, &status), ustr, -1, NULL, 0, &status);
 #else
 		needed = unorm_normalize(ustr, -1, mode, 0, NULL, 0, &status);
 #endif /* HAVE_UNICODE_UNORM2_H */
@@ -1310,7 +1310,7 @@ normalize(
 		norm_len = needed + 1;
 		norm = my_malloc(sizeof(UChar) * norm_len);
 #ifdef HAVE_UNICODE_UNORM2_H
-		(void) unorm2_normalize(unorm2_getInstance(NULL, unamep, mode, &status), ustr, -1, norm, norm_len, &status);
+		(void) unorm2_normalize(unorm2_getInstance(NULL, uni_namep, mode, &status), ustr, -1, norm, norm_len, &status);
 #else
 		(void) unorm_normalize(ustr, -1, mode, 0, norm, norm_len, &status);
 #endif /* HAVE_UNICODE_UNORM2_H */
@@ -1512,13 +1512,13 @@ parse_format_string(
 		tmp_date_str[0] = '\0';
 		d_fmt = tmp_date_str;
 		if (*in > '0' && *in <= '9') {
-			len = atoi(in);
+			len = (size_t) atoi(in);
 			for (; *in >= '0' && *in <= '9'; in++)
 				;
 		}
 		if (*in == ',') {
 			if (*++in > '0' && *in <= '9') {
-				len2 = atoi(in);
+				len2 = (size_t) atoi(in);
 				for (; *in >= '0' && *in <= '9'; in++)
 					;
 			}
@@ -1539,7 +1539,7 @@ parse_format_string(
 				endp = startp = tmpp;
 
 			if (endp) {
-				tmplen = endp - in;
+				tmplen = (size_t) (endp - in);
 
 				for (in++; *in && --tmplen; in++)
 					*d_fmt++ = *in;
@@ -1566,9 +1566,8 @@ parse_format_string(
 				if (cCOLS > min_cols && !(flags & GRP_DESC) && signal_context == cSelect) {
 					flags |= GRP_DESC;
 					fmt->show_grpdesc = TRUE;
-					if (len) {
+					if (len)
 						fmt->len_grpdesc = len;
-					}
 				} else
 					out -= 2;
 				break;
@@ -1587,7 +1586,7 @@ parse_format_string(
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 						if ((wtmp = char2wchar_t(buf)) != NULL) {
 							if (wcstombs(tmp, wtmp, sizeof(tmp) - 1) != (size_t) -1) {
-								fmt->len_date = strwidth(tmp);
+								fmt->len_date = (size_t) strwidth(tmp);
 							}
 							free(wtmp);
 						}
@@ -1703,9 +1702,8 @@ parse_format_string(
 				/* Subject */
 				if (cCOLS > min_cols && !(flags & SUBJECT) && signal_context == cGroup) {
 					flags |= SUBJECT;
-					if (len) {
+					if (len)
 						fmt->len_subj = len;
-					}
 				} else
 					out -= 2;
 				break;
@@ -1725,9 +1723,8 @@ parse_format_string(
 				if (cCOLS > min_cols && !(flags & THREAD_TREE) && signal_context == cThread) {
 					flags |= THREAD_TREE;
 					show_subject = TRUE;
-					if (len) {
+					if (len)
 						fmt->len_subj = len;
-					}
 				} else
 					out -= 2;
 				break;
@@ -1779,7 +1776,7 @@ parse_format_string(
 				fmt->flags_offset = tinrc.draw_arrow ? 2 : 0;
 				fmt->ucnt_offset = tinrc.draw_arrow ? 10 : 8;
 				fmt->len_grpname_dsc = 32;
-				fmt->len_grpname_max = cCOLS - cnt - 1;
+				fmt->len_grpname_max = (size_t) cCOLS - cnt - 1;
 				fmt->len_ucnt = 5;
 				break;
 
@@ -1805,36 +1802,36 @@ parse_format_string(
 		}
 
 		if (flags & SUBJECT)
-			fmt->len_from = (cCOLS - cnt - 1) / 3;
+			fmt->len_from = ((size_t) cCOLS - cnt - 1) / 3;
 		else
-			fmt->len_from = (cCOLS - cnt - 1);
+			fmt->len_from = ((size_t) cCOLS - cnt - 1);
 
-		fmt->len_subj = cCOLS - fmt->len_from - cnt - 1;
+		fmt->len_subj = (size_t) cCOLS - fmt->len_from - cnt - 1;
 	} else {
 		if (flags & (GRP_NAME | GRP_DESC))
-			fmt->len_grpname_max = cCOLS - cnt - 1;
+			fmt->len_grpname_max = (size_t) cCOLS - cnt - 1;
 
 		if (!show_description && !(flags & GRP_NAME))
 			fmt->len_grpname_max = 0;
 
-		if (flags & DATE && fmt->len_date > (cCOLS - cnt - 1))
-			fmt->len_date = (cCOLS - cnt - 1);
+		if (flags & DATE && fmt->len_date > ((size_t) cCOLS - cnt - 1))
+			fmt->len_date = ((size_t) cCOLS - cnt - 1);
 
-		if (flags & DATE && (!fmt->len_date_max || fmt->len_date_max > (cCOLS - cnt - 1)))
+		if (flags & DATE && (!fmt->len_date_max || fmt->len_date_max > ((size_t) cCOLS - cnt - 1)))
 			fmt->len_date_max = fmt->len_date;
 
-		if (flags & FROM && (!fmt->len_from || fmt->len_from > (cCOLS - fmt->len_date_max - cnt - 1))) {
+		if (flags & FROM && (!fmt->len_from || fmt->len_from > ((size_t) cCOLS - fmt->len_date_max - cnt - 1))) {
 			if (flags & (SUBJECT | THREAD_TREE)) {
 				if (fmt->len_subj)
-					fmt->len_from = cCOLS - fmt->len_date_max - fmt->len_subj - cnt - 1;
+					fmt->len_from = (size_t) cCOLS - fmt->len_date_max - fmt->len_subj - cnt - 1;
 				else
-					fmt->len_from = (cCOLS - fmt->len_date_max - cnt - 1) / 3;
+					fmt->len_from = ((size_t) cCOLS - fmt->len_date_max - cnt - 1) / 3;
 			} else
-				fmt->len_from = (cCOLS - fmt->len_date_max - cnt - 1);
+				fmt->len_from = ((size_t) cCOLS - fmt->len_date_max - cnt - 1);
 		}
 
-		if (flags & (SUBJECT | THREAD_TREE) && (!fmt->len_subj || fmt->len_subj > (cCOLS - fmt->len_from - fmt->len_date_max - cnt - 1)))
-			fmt->len_subj = (cCOLS - fmt->len_from - fmt->len_date_max - cnt - 1);
+		if (flags & (SUBJECT | THREAD_TREE) && (!fmt->len_subj || fmt->len_subj > ((size_t) cCOLS - fmt->len_from - fmt->len_date_max - cnt - 1)))
+			fmt->len_subj = ((size_t) cCOLS - fmt->len_from - fmt->len_date_max - cnt - 1);
 	}
 }
 
